module.exports = defineTest({
	description: 'supports labels when breaking control flow'
});
